summaryrefslogtreecommitdiffstats
path: root/quanta/src/dtds.h
diff options
context:
space:
mode:
Diffstat (limited to 'quanta/src/dtds.h')
-rw-r--r--quanta/src/dtds.h4
1 files changed, 2 insertions, 2 deletions
diff --git a/quanta/src/dtds.h b/quanta/src/dtds.h
index ae7c28f1..4f351182 100644
--- a/quanta/src/dtds.h
+++ b/quanta/src/dtds.h
@@ -209,11 +209,11 @@ private:
/** Reads the tags from the tag files.
*
* @param fileName path of the tag file
* @param tqparentDTD the DTD where the tags belog to
* @param tagList the list where the tags are inserted
* @return the number of read tags.
*/
- uint readTagFile(const TQString& fileName, DTDStruct* tqparentDTD, TQTagList *tagList);
+ uint readTagFile(const TQString& fileName, DTDStruct* parentDTD, TQTagList *tagList);
/** Parses the dom document and retrieve the tag attributes
*
@@ -209,11 +209,11 @@ private:
*
* @param fileName path of the tag file
- * @param tqparentDTD the DTD where the tags belog to
+ * @param parentDTD the DTD where the tags belog to
* @param tagList the list where the tags are inserted
* @return the number of read tags.